@@ -82,6 +82,10 @@ Add a list of job servers to a client. The format for the server list is:
 SERVER[:PORT][,SERVER[:PORT]]... No socket I/O happens here, it is just added
 to a list. Returns a standard gearman return value.
 
+=head2 $client->remove_servers()
+
+Remove all servers currently associated with the client.
+
 =head2 $client->options()
 
 Get options for a client.
@@ -250,6 +254,7 @@ Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
+Copyright (C) 2013 Data Differential, ala Brian Aker, http://datadifferential.com/
 Copyright (C) 2009-2010 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
@@ -267,6 +272,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Dennis Schoen <dennis@blogma.de>
+Brian Aker <brian@tangent.org>
 
-=cut
\ No newline at end of file
+=cut
