@@ -73,6 +73,7 @@ Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
+Copyright (C) 2013 Data Differential, ala Brian Aker, http://datadifferential.com/
 Copyright (C) 2009-2010 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
@@ -90,6 +91,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Dennis Schoen <dennis@blogma.de>
+Brian Aker <brian@tangent.org>
 
-=cut
\ No newline at end of file
+=cut
